OppiaMobile Server Change Log
================================

v0.6.1 - not yet released
------------------------------
* https://github.com/DigitalCampus/django-oppia/issues/213 - reset password using email address
* https://github.com/DigitalCampus/moodle-block_oppia_mobile_export/issues/issues/issue/117 - add support for Moodle url activities

v0.6.0 - released 22 Dec 2014
------------------------------
* https://github.com/DigitalCampus/django-oppia/issues/211 - save phone no on register via API
* https://github.com/DigitalCampus/django-oppia/issues/212 - Fix quiz titles

Previous Versions
------------------

.. toctree::
   :maxdepth: 2
   
   changelog_server_v0.5
   changelog_server_v0.4
   changelog_server_v0.3
   changelog_server_v0.2
   changelog_server_v0.1
